#include <QFileDialog>

#include "backenddialog.h"

BackEndDialog::BackEndDialog(QWidget *parent)
    : QDialog(parent)
{
    setupUi(this);

    mainWindow = qobject_cast<MainWindow*>(this->parent());
    setWindowTitle(windowTitle().arg(MainWindow::getAppTitle()));

    label_Status_Orig = label_Status->text();
    label_Version_Orig = label_Version->text();

    lineEdit_fileName->setText(mainWindow->getBackEndFileName());
    refreshStatusAndVersion(true);

    isAccepted = false;
}

BackEndDialog::~BackEndDialog(){
    if (isAccepted){
        mainWindow->setBackEndFileName(lineEdit_fileName->text());
        QString version = label_Version->text().remove(QRegExp("^.*: ")); // "Version: 1.6.2" -> "1.6.2"
        mainWindow->setBackEndVersion(version);
    }
}

void BackEndDialog::refreshStatusAndVersion(bool isInit){
    bool isStatusOk = false;
    QString status = "<b><font color=red>"+tr("invalid")+"</font></b>";
    QString version = "";
    QString backEndVersion = isInit ? mainWindow->getBackEndVersion() : mainWindow->findBackEndVersionByProcess(lineEdit_fileName->text());
    if (backEndVersion.isEmpty()){
        status = "<b><font color=red>"+tr("invalid (not found)")+"</font></b>";
    }
    else if(!mainWindow->isBackEndAvailable(backEndVersion))
    {
        status = "<b><font color=red>"+tr("invalid (%1 or later required)").arg(mainWindow->getRequiredBackEndVersion())+"</font></b>";
        version = backEndVersion;
    }
    else{
        status = "<b><font color=green>"+tr("ok")+"</font></b>";
        isStatusOk = true;
        version = backEndVersion;
    }
    label_Status->setText(label_Status_Orig.arg(status));
    label_Version->setText(label_Version_Orig.arg(version));
    buttonBox->button(QDialogButtonBox::Ok)->setEnabled(isStatusOk);
}

void BackEndDialog::accept(){
    isAccepted = true;
    return QDialog::accept();
}

void BackEndDialog::on_toolButton_fileName_clicked(){
    QString fileName = QFileDialog::getOpenFileName(this, tr("Select back end mp3gain executable file"),
                                                    lineEdit_fileName->text(), QString());
    if (!fileName.isEmpty()){
        lineEdit_fileName->setText(fileName);
        refreshStatusAndVersion(false);
    }
}

void BackEndDialog::on_lineEdit_fileName_editingFinished(){
    refreshStatusAndVersion(false);
}
